@@ -47,7 +47,7 @@ def scrub(result):
             for i, v in enumerate(output):
                 if v is SQL_NULL:
                     null_locations.append((output, i))
-            return scrub_literal(output)
+            return output
     else:
         # ATTEMPT A DICT INTERPRETATION
         try:
@@ -185,6 +185,13 @@ binary_ops = {
 }
 
 
+def to_trim_call(tokens):
+    frum = tokens['from']
+    if not frum:
+        return {"trim": tokens["chars"]}
+    return {"trim": frum, "characters": tokens['chars']}
+
+
 def to_json_call(tokens):
     # ARRANGE INTO {op: params} FORMAT
     op = tokens["op"].lower()
@@ -232,7 +239,7 @@ def to_switch_call(tokens):
     for c in cases:
         c["when"] = {"eq": [value, c["when"]]}
     elze = tokens["else"]
-    if elze:
+    if elze != None:
         cases.append(elze)
     return {"case": cases}
 
@@ -389,6 +396,12 @@ hexNum = (
 )
 
 # STRINGS
-sqlString = Regex(r"\'(\'\'|[^'])*\'").addParseAction(to_string)
+ansi_string = Regex(r"\'(\'\'|[^'])*\'").addParseAction(to_string)
+mysql_doublequote_string = Regex(r'\"(\"\"|[^"])*\"').addParseAction(to_string)
+
+# BASIC IDENTIFIERS
+ansi_ident = Regex(r'\"(\"\"|[^"])*\"').addParseAction(unquote)
+mysql_backtick_ident = Regex(r"\`(\`\`|[^`])*\`").addParseAction(unquote)
+sqlserver_ident = Regex(r"\[(\]\]|[^\]])*\]").addParseAction(unquote)
 
 expr = Forward()
